@@ -1,5 +1,5 @@
 import test from 'ava';
-import m from './';
+import m from '.';
 
 test('throw if input is not a string', t => {
 	t.throws(() => m(5), 'Expected `input` to be a `string`, got `number`');
@@ -11,7 +11,8 @@ test('throw if count is not a number', t => {
 });
 
 test('throw if indent is not a string', t => {
-	t.throws(() => m('foo', 1, 1), 'Expected `indent` to be a `string`, got `number`');
+	t.throws(() => m('foo', 1, 1), 'Expected `options.indent` to be a `string`, got `number`'); // Old syntax
+	t.throws(() => m('foo', 1, {indent: 1}), 'Expected `options.indent` to be a `string`, got `number`');
 });
 
 test('indent each line in a string', t => {
@@ -23,12 +24,26 @@ test('indent each line in a string', t => {
 
 test('not indent whitespace only lines', t => {
 	t.is(m('foo\nbar\n', 1), ' foo\n bar\n');
+	t.is(m('foo\nbar\n', 1, {includeEmptyLines: false}), ' foo\n bar\n');
+	t.is(m('foo\nbar\n', 1, {includeEmptyLines: null}), ' foo\n bar\n');
+});
+
+test('indent every line if options.blank is true', t => {
+	t.is(m('foo\n\nbar\n	', 1, {includeEmptyLines: true}), ' foo\n \n bar\n 	');
 });
 
 test('indent with leading whitespace', t => {
 	t.is(m(' foo\n bar\n', 1), '  foo\n  bar\n');
 });
 
+test('indent with custom string', t => {
+	t.is(m('foo\nbar\n', 1, {indent: '♥'}), '♥foo\n♥bar\n');
+});
+
+test('indent with custom string and old syntax', t => {
+	t.is(m('foo\nbar\n', 1, '#'), '#foo\n#bar\n');
+});
+
 test('not indent when count is 0', t => {
 	t.is(m('foo\nbar\n', 0), 'foo\nbar\n');
 });
